AliAnalysisGrid* CreateAlienHandler(const char *lhcPeriod = "LHC15o") {
  // Check if user has a valid token, otherwise make one. This has limitations.
  // One can always follow the standard procedure of calling alien-token-init then
  //   source /tmp/gclient_env_$UID in the current shell.
  AliAnalysisAlien *plugin = new AliAnalysisAlien();
  
  // Set the run mode (can be "full", "test", "offline", "submit" or "terminate")
  //plugin->SetRunMode("test");
  //plugin->SetRunMode("offline");
  //plugin->SetRunMode("submit");
  //plugin->SetRunMode("full");
  plugin->SetRunMode("terminate");
  plugin->SetNtestFiles(5); // Relevant only for run mode "test" 

  // Set versions of used packages
  plugin->SetAPIVersion("V1.1x");
  plugin->SetAliPhysicsVersion("vAN-20171015-1");  
  
  // Declare input data to be processed - can be done in two ways:
  TString periodIdentifier = "/alice/data/2015/";
  periodIdentifier += lhcPeriod;
  plugin->SetGridDataDir(periodIdentifier.Data());
  plugin->SetDataPattern("*pass2_lowIR/AOD/*AliAOD.root");
  plugin->SetRunPrefix("000"); // IMPORTANT!

  Int_t runNumber = 0;
  Int_t runCounter = 0;
  TString runListFileName = lhcPeriod; runListFileName += ".txt";
  ifstream inputFile;
  inputFile.open(runListFileName);
  while(true) {
    inputFile >> runNumber;
    if(inputFile.eof()) break;

    Printf("==========================================");
    Printf("Run %d added",runNumber);
    plugin->AddRunNumber(runNumber);
    runCounter += 1;
  }
  plugin->SetOutputToRunNo();  

  // Define alien work directory where all files will be copied. Relative to alien $HOME.
  TString outputDirectory = "Tutorial/"; outputDirectory += lhcPeriod;
  plugin->SetGridWorkingDir(outputDirectory.Data());
  // Declare alien output directory. Relative to working directory.
  plugin->SetGridOutputDir("output"); // In this case will be $HOME/work/output
  // Declare the analysis source files names separated by blancs. To be compiled runtime
  // using ACLiC on the worker nodes.
  plugin->SetAnalysisSource("AliAnalysisTaskPtSpectra.cxx");
  // Declare all libraries (other than the default ones for the framework. These will be
  // loaded by the generated analysis macro. Add all extra files (task .cxx/.h) here.
  plugin->SetAdditionalLibs("AliAnalysisTaskPtSpectra.h AliAnalysisTaskPtSpectra.cxx");
  
  // Do not specify your outputs by hand anymore:
  plugin->SetDefaultOutputs(kTRUE);
  // Optionally set a name for the generated analysis macro (default MyAnalysis.C)
  plugin->SetAnalysisMacro("taskTutorialAnalysis.C");
  // Optionally set maximum number of input files/subjob (default 100, put 0 to ignore)
  plugin->SetSplitMaxInputFileNumber(100);
  // Optionally set number of runs per masterjob:
  plugin->SetNrunsPerMaster(1);
 
  // Optionally set time to live (default 30000 sec)
  plugin->SetTTL(30000);
  // Optionally set input format (default xml-single)
  plugin->SetInputFormat("xml-single");
  // Optionally modify the name of the generated JDL (default analysis.jdl)
  plugin->SetJDLName("taskTutorialAnalysis.jdl");
  // Optionally modify job price (default 1)
  plugin->SetPrice(1);      
  // Optionally modify split mode (default 'se')    
  plugin->SetSplitMode("se");

  //Merging
  plugin->SetMergeViaJDL(kTRUE);

  return plugin;
}
