enum anaModes {mLocal,mGrid};
//mLocal: Analyze locally files in your computer using aliroot
//mGrid: Analyze files on Grid via AliEn plug-in and using precompiled FLOW libraries                                         
void runPtSpectra(Int_t mode = mGrid,
		  UInt_t gFilterBit = 768,
		  const char* lhcPeriod = "LHC15o",
		  const char* directoryFile = "/dcache/alice/panosch/alice/data/2015/LHC15o/000244917/pass2_lowIR/"){
  // Time:                                                                                                                    
  TStopwatch timer;
  timer.Start();

  gROOT->ProcessLine(".include $ROOTSYS/include"); 
  gROOT->ProcessLine(".include $ALICE_ROOT/include");
  gROOT->ProcessLine(".include $ALICE_PHYSICS/include");
    
  gSystem->Load("libCore");
  gSystem->Load("libGeom");
  gSystem->Load("libVMC");
  gSystem->Load("libPhysics");
  gSystem->Load("libTree");
  gSystem->Load("libSTEERBase");
  gSystem->Load("libESD");
  gSystem->Load("libAOD");
  gSystem->Load("libANALYSIS");
  gSystem->Load("libANALYSISalice");
  gSystem->Load("libEventMixing");
  gSystem->Load("libCORRFW");
  gSystem->Load("libPWGTools");
  
  AliAnalysisGrid *alienHandler = 0x0;
  AliAnalysisManager *mgr = new AliAnalysisManager("AnalysisMyTask"); 
  
  AliAODInputHandler *aodH = new AliAODInputHandler();
  mgr->SetInputEventHandler(aodH);
  
  TChain *chain = new TChain("aodTree");  
  if(mode == mLocal) {
    TSystemDirectory dir(directoryFile ,directoryFile);
    TList *files = dir.GetListOfFiles();
    if (files) {
      TSystemFile *file;
      TString filename;
      TIter next(files);
      while ((file=(TSystemFile*)next())) {
	filename = directoryFile;
	filename += file->GetName();
	//filename = directoryFile;
	filename += "/AliAOD.root";
	cout << "Adding: "<<filename.Data() << endl;
	chain->Add(filename.Data());
      }
    }
  }//mLocal mode
  if(mode == mGrid) {
    gROOT->LoadMacro("CreateAlienHandler.C");
    alienHandler = CreateAlienHandler(lhcPeriod);
    if (!alienHandler) return;
  }

  if(mode == mGrid)
    mgr->SetGridHandler(alienHandler);

  gROOT->LoadMacro("AliAnalysisTaskPtSpectra.cxx++g"); 
  gROOT->LoadMacro("AddTaskPtSpectra.C"); 
  
  AliAnalysisTaskPtSpectra *task = AddTaskPtSpectra(gFilterBit);
  
  // Run the analysis:
  if(!mgr->InitAnalysis()){return;}
  mgr->PrintStatus();
  if(mode == mLocal)
    mgr->StartAnalysis("local",chain);
  else if(mode == mGrid)
    mgr->StartAnalysis("grid");

  // Print real and CPU time used for analysis:
  timer.Stop();
  timer.Print();  
}
